# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['deutschland',
 'deutschland.tagesschau',
 'deutschland.tagesschau.api',
 'deutschland.tagesschau.apis',
 'deutschland.tagesschau.model',
 'deutschland.tagesschau.models']

package_data = \
{'': ['*']}

install_requires = \
['python-dateutil', 'urllib3>=1.25.3']

setup_kwargs = {
    'name': 'de-tagesschau',
    'version': '0.1.0',
    'description': 'Tagesschau API',
    'long_description': '# tagesschau\nDie Tagesschau ist eine Nachrichtensendung der ARD (Abkürzung für Arbeitsgemeinschaft der öffentlich-rechtlichen Rundfunkanstalten der Bundesrepublik Deutschland), die von ARD-aktuell in Hamburg produziert und mehrmals täglich ausgestrahlt wird. ARD-aktuell ist seit 1977 die zentrale Fernsehnachrichtenredaktion der ARD, bei welcher es sich wiederum um einen Rundfunkverbund handelt, der aus den Landesrundfunkanstalten und der Deutschen Welle besteht.<br>Über die hier dokumentierte API stehen auf [www.tagesschau.de](https://www.tagesschau.de) aktuelle Nachrichten und Medienbeiträge im JSON-Format zur Verfügung.<br>\n\nThis Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:\n\n- API version: 2.0.0\n- Package version: 0.1.0\n- Build package: org.openapitools.codegen.languages.PythonClientCodegen\n\n## Requirements.\n\nPython >= 3.6\n\n## Installation & Usage\n### pip install\n\n```sh\npip install deutschland[tagesschau]\n```\n\n### poetry install\n\n```sh\npoetry add deutschland -E tagesschau\n```\n\n### Setuptools\n\nInstall via [Setuptools](http://pypi.python.org/pypi/setuptools).\n\n```sh\npython setup.py install --user\n```\n(or `sudo python setup.py install` to install the package for all users)\n\n## Usage\n\nImport the package:\n```python\nfrom deutschland import tagesschau\n```\n\n## Getting Started\n\nPlease follow the [installation procedure](#installation--usage) and then run the following:\n\n```python\n\nimport time\nfrom deutschland import tagesschau\nfrom pprint import pprint\nfrom deutschland.tagesschau.api import default_api\nfrom deutschland.tagesschau.model.channels_response import ChannelsResponse\nfrom deutschland.tagesschau.model.homepage_response import HomepageResponse\nfrom deutschland.tagesschau.model.multimedia_response import MultimediaResponse\nfrom deutschland.tagesschau.model.news_response import NewsResponse\nfrom deutschland.tagesschau.model.search_response import SearchResponse\n# Defining the host is optional and defaults to https://www.tagesschau.de\n# See configuration.py for a list of all supported configuration parameters.\nconfiguration = tagesschau.Configuration(\n    host = "https://www.tagesschau.de"\n)\n\n\n\n# Enter a context with an instance of the API client\nwith tagesschau.ApiClient(configuration) as api_client:\n    # Create an instance of the API class\n    api_instance = default_api.DefaultApi(api_client)\n\n    try:\n        # Wichtige Nachrichten und Eilmeldungen\n        api_response = api_instance.api2()\n        pprint(api_response)\n    except tagesschau.ApiException as e:\n        print("Exception when calling DefaultApi->api2: %s\\n" % e)\n```\n\n## Documentation for API Endpoints\n\nAll URIs are relative to *https://www.tagesschau.de*\n\nClass | Method | HTTP request | Description\n------------ | ------------- | ------------- | -------------\n*DefaultApi* | [**api2**](docs/DefaultApi.md#api2) | **GET** /api2 | Wichtige Nachrichten und Eilmeldungen\n*DefaultApi* | [**channels**](docs/DefaultApi.md#channels) | **GET** /api2/channels | Aktuelle Kanäle\n*DefaultApi* | [**homepage**](docs/DefaultApi.md#homepage) | **GET** /api2/homepage | Ausgewählte aktuelle Nachrichten und Eilmeldungen\n*DefaultApi* | [**multimedia**](docs/DefaultApi.md#multimedia) | **GET** /api2/multimedia | Multimedia\n*DefaultApi* | [**news**](docs/DefaultApi.md#news) | **GET** /api2/news | Aktuelle Nachrichten und Eilmeldungen\n*DefaultApi* | [**newsfeed**](docs/DefaultApi.md#newsfeed) | **GET** /api2/newsfeed-101~_date-{datumsangabe}.json | Newsfeed\n*DefaultApi* | [**ressort**](docs/DefaultApi.md#ressort) | **GET** /api2/{ressort} | Ressort-spezifische Nachrichten\n*DefaultApi* | [**search**](docs/DefaultApi.md#search) | **GET** /api2/search | Suche\n\n\n## Documentation For Models\n\n - [ChannelsResponse](docs/ChannelsResponse.md)\n - [ChannelsResponseChannels](docs/ChannelsResponseChannels.md)\n - [HomepageResponse](docs/HomepageResponse.md)\n - [HomepageResponseNews](docs/HomepageResponseNews.md)\n - [HomepageResponseRegional](docs/HomepageResponseRegional.md)\n - [MultimediaResponse](docs/MultimediaResponse.md)\n - [NewsResponse](docs/NewsResponse.md)\n - [NewsResponseNews](docs/NewsResponseNews.md)\n - [SearchResponse](docs/SearchResponse.md)\n - [SearchResponseSearchResults](docs/SearchResponseSearchResults.md)\n\n\n## Documentation For Authorization\n\n All endpoints do not require authorization.\n\n## Author\n\nkontakt@bund.dev\n\n\n## Notes for Large OpenAPI documents\nIf the OpenAPI document is large, imports in tagesschau.apis and tagesschau.models may fail with a\nRecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:\n\nSolution 1:\nUse specific imports for apis and models like:\n- `from deutschland.tagesschau.api.default_api import DefaultApi`\n- `from deutschland.tagesschau.model.pet import Pet`\n\nSolution 2:\nBefore importing the package, adjust the maximum recursion limit as shown below:\n```\nimport sys\nsys.setrecursionlimit(1500)\nfrom deutschland import tagesschau\nfrom deutschland.tagesschau.apis import *\nfrom deutschland.tagesschau.models import *\n```\n\n',
    'author': 'BundesAPI',
    'author_email': 'kontakt@bund.dev',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bundesAPI/tagesschau-api',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6',
}


setup(**setup_kwargs)
